==> herculesteam-augeasproviders_ssh-2.0.0.tar.gz: herculesteam-augeasproviders_ssh-2.0.0/spec/unit/puppet/provider/sshd_config_subsystem/augeas_spec.rb <==
#!/usr/bin/env rspec

require 'spec_helper'

provider_class = Puppet::Type.type(:sshd_config_subsystem).provider(:augeas)

describe provider_class do
  before :each do
    FileTest.stubs(:exist?).returns false
    FileTest.stubs(:exist?).with('/etc/ssh/sshd_config').returns true
  end

  context "with empty file" do
    let(:tmptarget) { aug_fixture("empty") }
    let(:target) { tmptarget.path }

    it "should create simple new entry" do
      apply!(Puppet::Type.type(:sshd_config_subsystem).new(
        :name     => "sftp",
        :command  => "/usr/lib/openssh/sftp-server",
        :target   => target,
        :provider => "augeas"
      ))

      aug_open(target, "Sshd.lns") do |aug|
        aug.get("Subsystem/sftp").should == "/usr/lib/openssh/sftp-server"
      end
    end
  end

  context "with full file" do
    let(:tmptarget) { aug_fixture("full") }
    let(:target) { tmptarget.path }

    it "should list instances" do
      provider_class.stubs(:target).returns(target)
      inst = provider_class.instances.map { |p|
        {
          :name    => p.get(:name),
          :ensure  => p.get(:ensure),
          :command => p.get(:command),
        }
      }

      inst.size.should == 1
      inst[0].should == {:name=>"sftp", :ensure=>:present,
	                 :command=>"/usr/libexec/openssh/sftp-server"}
    end

    describe "when creating settings" do
      it "should add it before Match block" do
        apply!(Puppet::Type.type(:sshd_config_subsystem).new(
          :name     => "mysub",
          :command  => "/bin/bash",
          :target   => target,
          :provider => "augeas"
        ))

        aug_open(target, "Sshd.lns") do |aug|
          aug.get("Subsystem/mysub").should == "/bin/bash"
        end
      end
    end

    describe "when deleting settings" do
      it "should delete a setting" do
        expr = "Subsystem/sftp"
        aug_open(target, "Sshd.lns") do |aug|
          aug.match(expr).should_not == []
        end

        apply!(Puppet::Type.type(:sshd_config_subsystem).new(
          :name     => "sftp",
          :ensure   => "absent",
          :target   => target,
          :provider => "augeas"
        ))

        aug_open(target, "Sshd.lns") do |aug|
          aug.match(expr).should == []
        end
      end
    end

    describe "when updating settings" do
      it "should replace a setting" do
        apply!(Puppet::Type.type(:sshd_config_subsystem).new(
          :name     => "sftp",
          :command  => "/bin/bash",
          :target   => target,
          :provider => "augeas"
        ))

        aug_open(target, "Sshd.lns") do |aug|
          aug.get("Subsystem/sftp").should == "/bin/bash"
        end
      end
    end
  end

  context "with broken file" do
    let(:tmptarget) { aug_fixture("broken") }
    let(:target) { tmptarget.path }

    it "should fail to load" do
      txn = apply(Puppet::Type.type(:sshd_config_subsystem).new(
        :name     => "sftp",
        :command  => "/bin/bash",
        :target   => target,
        :provider => "augeas"
      ))

      txn.any_failed?.should_not == nil
      @logs.first.level.should == :err
      @logs.first.message.include?(target).should == true
    end
  end
end

==> herculesteam-augeasproviders_ssh-4.0.0.tar.gz: herculesteam-augeasproviders_ssh-4.0.0/spec/unit/puppet/provider/sshd_config_subsystem/augeas_spec.rb <==
#!/usr/bin/env rspec

require 'spec_helper'

provider_class = Puppet::Type.type(:sshd_config_subsystem).provider(:augeas)

describe provider_class do
  before :each do
    FileTest.stubs(:exist?).returns false
    FileTest.stubs(:exist?).with('/etc/ssh/sshd_config').returns true
  end

  context "with empty file" do
    let(:tmptarget) { aug_fixture("empty") }
    let(:target) { tmptarget.path }

    it "should create simple new entry" do
      apply!(Puppet::Type.type(:sshd_config_subsystem).new(
        :name     => "sftp",
        :command  => "/usr/lib/openssh/sftp-server",
        :target   => target,
        :provider => "augeas"
      ))

      aug_open(target, "Sshd.lns") do |aug|
        expect(aug.get("Subsystem/sftp")).to eq("/usr/lib/openssh/sftp-server")
      end
    end

    it "should create new comment before entry" do
      apply!(Puppet::Type.type(:sshd_config_subsystem).new(
        :name      => "sftp",
        :command  => "/usr/lib/openssh/sftp-server",
        :target   => target,
        :provider => "augeas",
        :comment   => 'Use the external subsystem'
      ))

      aug_open(target, "Sshd.lns") do |aug|
        expect(aug.get("#comment[following-sibling::Subsystem[sftp]]")).to eq("sftp: Use the external subsystem")
      end
    end
  end

  context "with full file" do
    let(:tmptarget) { aug_fixture("full") }
    let(:target) { tmptarget.path }

    it "should list instances" do
      provider_class.stubs(:target).returns(target)
      inst = provider_class.instances.map { |p|
        {
          :name    => p.get(:name),
          :ensure  => p.get(:ensure),
          :command => p.get(:command),
        }
      }

      expect(inst.size).to eq(1)
      expect(inst[0]).to eq({:name=>"sftp", :ensure=>:present,
                             :command=>"/usr/libexec/openssh/sftp-server"})
    end

    describe "when creating settings" do
      it "should add it before Match block" do
        apply!(Puppet::Type.type(:sshd_config_subsystem).new(
          :name     => "mysub",
          :command  => "/bin/bash",
          :target   => target,
          :provider => "augeas"
        ))

        aug_open(target, "Sshd.lns") do |aug|
          expect(aug.get("Subsystem/mysub")).to eq("/bin/bash")
        end
      end

      it "should create new comment before entry" do
        apply!(Puppet::Type.type(:sshd_config_subsystem).new(
          :name      => "sftp2",
          :command  => "/usr/lib/openssh/sftp-server2",
          :target   => target,
          :provider => "augeas",
          :comment   => 'Use the external subsystem'
        ))

        aug_open(target, "Sshd.lns") do |aug|
          expect(aug.get("#comment[following-sibling::Subsystem[sftp2]][last()]")).to eq("sftp2: Use the external subsystem")
        end
      end
    end

    describe "when deleting settings" do
      it "should delete a setting" do
        expr = "Subsystem/sftp"
        aug_open(target, "Sshd.lns") do |aug|
          expect(aug.match(expr)).not_to eq([])
        end

        apply!(Puppet::Type.type(:sshd_config_subsystem).new(
          :name     => "sftp",
          :ensure   => "absent",
          :target   => target,
          :provider => "augeas"
        ))

        aug_open(target, "Sshd.lns") do |aug|
          expect(aug.match(expr)).to eq([])
        end
      end

      it "should delete a comment" do
        apply!(Puppet::Type.type(:sshd_config_subsystem).new(
          :name      => "sftp",
          :command  => "/usr/lib/openssh/sftp-server",
          :target   => target,
          :provider => "augeas",
        ))

        aug_open(target, "Sshd.lns") do |aug|
          expect(aug.get("#comment[following-sibling::Subsystem[sftp][1]]")).to eq(nil)
        end
      end
    end

    describe "when updating settings" do
      it "should replace a setting" do
        apply!(Puppet::Type.type(:sshd_config_subsystem).new(
          :name     => "sftp",
          :command  => "/bin/bash",
          :target   => target,
          :provider => "augeas"
        ))

        aug_open(target, "Sshd.lns") do |aug|
          expect(aug.get("Subsystem/sftp")).to eq("/bin/bash")
        end
      end

      it "should replace the comment" do
        apply!(Puppet::Type.type(:sshd_config_subsystem).new(
          :name      => "sftp",
          :command  => "/usr/lib/openssh/sftp-server",
          :target   => target,
          :provider => "augeas",
          :comment   => 'A different comment'
        ))

        aug_open(target, "Sshd.lns") do |aug|
          expect(aug.get("#comment[following-sibling::Subsystem[sftp]][last()]")).to eq("sftp: A different comment")
        end
      end
    end
  end

  context "with broken file" do
    let(:tmptarget) { aug_fixture("broken") }
    let(:target) { tmptarget.path }

    it "should fail to load" do
      txn = apply(Puppet::Type.type(:sshd_config_subsystem).new(
        :name     => "sftp",
        :command  => "/bin/bash",
        :target   => target,
        :provider => "augeas"
      ))

      expect(txn.any_failed?).not_to eq(nil)
      expect(@logs.first.level).to eq(:err)
      expect(@logs.first.message.include?(target)).to eq(true)
    end
  end
end
